@@ -89,21 +89,24 @@ def main():
     
     #get user name for in log files
     if(data.user==""):
-        text = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
-                                                                                             "It will be used in the records file, this makes it easier\n" + \
-                                                                                             "when you want to share your sleep pattern with others.")
-        if(text != ""):
-            data.user=text[0]
-            config.set('main', 'user', str(data.user))    
-        else:
-            pass
-    print "User name:",  data.user
+        EditUserName()
 
     sys.exit(app.exec_())
 
 
 
 
+def EditUserName():
+    text = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
+                                                                                             "It will be used in the records file, this makes it easier\n" + \
+                                                                                             "when you want to share your sleep pattern with others.", 0,  data.user)
+    if(text != ""):
+        data.user=text[0]
+        config.set('main', 'user', str(data.user))    
+    else:
+        pass
+    print "User name:",  data.user
+
 
 ###########################################################################
 #  Gets called every second,
@@ -325,11 +328,16 @@ class frmStartWindow(QMainWindow):
             if(l>0):
                 data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
             else: #no logfiles in logfolder, show "open file" dialog
-#                tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
                 tmp=ViewWindow.ShowFileDialog()
-                if(tmp==""): return #only continue if valid log file selected
+                if(not os.path.exists(tmp)): #only continue if valid log file selected
+                    StartWindow.show()
+                    ViewWindow.hide()
+                    return #only continue if valid log file selected
                 tmp2=tmp.split("/")
                 l=len(tmp2)    
+#                if(tmp2[l-1]==""): #no file selected
+#                    print "filename=empty"
+#                    return
                 data.logfilename=tmp2[l-1]
                 data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
                 print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
@@ -340,7 +348,11 @@ class frmStartWindow(QMainWindow):
         ViewWindowGraph = ViewWindowCanvas(self)
         ViewWindow.ShowLogFile()
         
-        ViewWindow.show()
+        if(data.logfilename!=""):
+            print "ViewWindow.show()"
+            ViewWindow.show()
+        else:
+            "No valid file selected"
 #        StartWindow.hide()
         
         
@@ -560,7 +572,7 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), self.NextLogFile)
         QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), self.LastLogFile)
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
-        QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.Open)
+        QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
         QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
@@ -584,7 +596,7 @@ class frmViewWindow(QMainWindow):
 
 
     def UpdateScreen(self):
-        shortfolder=string.replace(data.logfolder, "/home/user/MyDocs", "~")
+        shortfolder=string.replace(data.logfolder, data.homedir, "~")
         self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
 #        self.ui.lblStarttime.setText("Start: "+str(data.arrData[0][0]))
 #        self.ui.lblStoptime.setText("End: "+str(data.arrData[0][data.arrDataIndex-1]))
@@ -632,7 +644,7 @@ class frmViewWindow(QMainWindow):
             QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
         elif(r==2): #file does not exist
 #            closeEvent(0)
-            self.Open()
+            self.OpenRecord()
             return
         LoadFileList()
         ProcessData()
@@ -701,11 +713,6 @@ class frmViewWindow(QMainWindow):
             if(l>0):
                 data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
             else: #no logfiles in logfolder, show "open file" dialog
-#                x=self.ShowFileDialog()
-#                if(x==""): 
-#                    self.closeEvent("") #no file selected, close
-#                    return
-#                data.logfilename=x
                 tmp=self.ShowFileDialog()
                 if(tmp==""): #only continue if valid log file selected
                     self.closeEvent("") #no file selected, close
@@ -720,9 +727,14 @@ class frmViewWindow(QMainWindow):
 
 
 
-    def Open(self):
+    def OpenRecord(self):
         tmp=self.ShowFileDialog()
-        if(tmp==""): return #only continue if valid log file selected
+        if(not os.path.exists(tmp)): #only continue if valid log file selected
+            print "OpenRecord: File does not exist"
+#            ViewWindow.hide()
+#            StartWindow.show()
+            return 
+        print "OpenRecord: File ok"
         tmp2=tmp.split("/")
         l=len(tmp2)    
         data.logfilename=tmp2[l-1]
@@ -733,7 +745,9 @@ class frmViewWindow(QMainWindow):
     
     
     
-    def ShowFileDialog(self):
+    def ShowFileDialog(self):        
+        data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
+        print "Open file dialog in:",  data.logfolder
         tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
         print "Selected file:",  tmp
 #        tmp2=tmp.split("/")
@@ -782,15 +796,15 @@ class frmConfigWindow(QMainWindow):
         self.ui = Ui_ConfigWindow()
         self.ui.setupUi(self)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
-        
-      
+              
+        QtCore.QObject.connect(self.ui.bEditUserName, QtCore.SIGNAL("clicked()"), self.EditUserName)
         
         
 
     def UpdateScreen(self):
         if(data.OfflineMode=="True"): self.ui.cOfflineMode.setChecked(True)
         else: self.ui.cOfflineMode.setChecked(False)        
-        self.ui.txtUserName.setPlainText(str(data.user))
+        self.ui.lblUserName.setText(str(data.user))
 
 
     def closeEvent(self, event):        
@@ -798,17 +812,16 @@ class frmConfigWindow(QMainWindow):
                 data.OfflineMode="True"
         else: 
             data.OfflineMode="False"
-        config.set('main', 'OfflineMode', str(data.OfflineMode))      
-        
-        data.user=str(self.ui.txtUserName.toPlainText())
+        config.set('main', 'OfflineMode', str(data.OfflineMode))   
         config.set('main', 'user', str(data.user))      
         
         ConfigWindow.close()
         StartWindow.show()
 
 
-
-
+    def EditUserName(self):
+        EditUserName()
+        self.ui.lblUserName.setText(str(data.user))
 
 
 
